@@ -324,7 +324,7 @@ def bar(obj, return_index=False, bar_len_total=50, bar_str='█', end='', step=1
     print(end=end)
 
 
-def bar2(now, total, need_print=True, bar_len_total=50, bar_str='█', info=None):
+def bar2(now, total, need_print=True, bar_len_total=30, bar_str='█', info=None):
     """
     打印输出进度条
     now: 当前进度
@@ -336,9 +336,9 @@ def bar2(now, total, need_print=True, bar_len_total=50, bar_str='█', info=None
 
     bar_len_now = bar_len_total * now // total  # 当前轮次需要打印的bar_str个数
     if info is None:
-        string = f"{now / total:<.0%}|{bar_str * bar_len_now:<{bar_len_total}}| {now}/{total}"
+        string = f"{now / total:>8.2%}|{bar_str * bar_len_now:　<{bar_len_total}}| {now}/{total}"
     else:
-        string = f"{now / total:<.0%}|{bar_str * bar_len_now:<{bar_len_total}}| {now}/{total}  {info}"
+        string = f"{now / total:>8.2%}|{bar_str * bar_len_now:　<{bar_len_total}}| {now}/{total}  {info}"
     if need_print:
         print(f"\r{string}",end='')
     else:
@@ -538,14 +538,15 @@ class Timer:
         return ts
 
     @staticmethod
-    def datebetween(string1, string2, format_str='%Y-%m-%d %H:%M:%S'):
+    def datebetween(string1, string2, format_str1='%Y-%m-%d %H:%M:%S', format_str2='%Y-%m-%d %H:%M:%S'):
         """
         求两个
         :param date_:  datatime类 实例对象
-        :param format_str: 字符型， string参数的时间格式
+        :param format_str1: 字符型， string1参数的时间格式
+        :param format_str2: 字符型， string2参数的时间格式
         :return:  整型时间戳
         """
-        return datetime.datetime.strptime(string1, '%Y-%m-%d %H:%M:%S') - datetime.datetime.strptime(string2, '%Y-%m-%d %H:%M:%S')
+        return datetime.datetime.strptime(string1, format_str1) - datetime.datetime.strptime(string2, format_str2)
 
 class GetFirstLetter(object):
     def is_contain_chinese(self, check_str):
@@ -612,7 +613,7 @@ class Cpen:
                 break
             yield line
 
-    def readlines(self, num_lines=10000):
+    def readlines(self, num_lines=100000):
         while True:
             lines = self.f.readlines(num_lines)
             if not lines:
